@@ -91,6 +91,7 @@ class FileX:
 
                 new_unique_years = [year + n for n in range(len(unique_years))]
 
+                # The way It is written, It allows only two years consecutively
                 self._planting = [my_date.replace(year = new_unique_years[0])
                                   if my_date.year == unique_years[0]
                                   else my_date.replace(year = new_unique_years[1])
@@ -110,7 +111,7 @@ class FileX:
 
 
 
-    def set_harvest(self, n_harvest, h_from, h_by, year, h_list=None, method="seq"):
+    def set_harvest(self, n_harvest, h_from, h_by, year, h_list=None, h_dap=None, method="seq"):
         """
         Method to define harvest dates. It uses date sequence logic.
 
@@ -163,11 +164,19 @@ class FileX:
 
             self._harvest = [date.strftime("%y%j") for date in self._harvest]
 
+        elif method == "dap":
+            
+            if "phf" not in self._design:
+                raise ValueError("havest method 'dap' must be used with 'phf' design.")
+
+            self._harvest = [p_date + td(days=int(h_dap)) for p_date in self._planting]
+            self._harvest = [date.strftime("%y%j") for date in self._harvest]
+
         else:
             raise AttributeError(f"\n\n Valor '{method}' não reconhecido para o argumento 'method' \n")
 
 
-    def set_controls(self, sim_start, date_start = None, years=1):
+    def set_controls(self, sim_start, date_start = None, years=1, auto_irrigation=None):
         """
         Method to define simulation start date and soil water available at the simulation beginning.
 
@@ -189,6 +198,22 @@ class FileX:
 
         self.years = years
 
+        if auto_irrigation:
+            self.auto_irrig = "A"
+            self.auto_irrig_method = auto_irrigation["method"]
+            self.auto_irrig_depth = auto_irrigation["management_depth"]
+            self.auto_irrig_threshold = auto_irrigation["threshold"]
+            self.auto_irrig_endpoint = auto_irrigation["end_point"]
+            self.auto_irrig_effic = auto_irrigation["efficiency"]
+        else: 
+            self.auto_irrig = "R"
+            self.auto_irrig_method = "04"
+            self.auto_irrig_depth = 60
+            self.auto_irrig_threshold = 60
+            self.auto_irrig_endpoint = 100
+            self.auto_irrig_effic = 0.8
+
+
     def set_field(self, code_id, soil_id, water=1):
         """
         Method to define simulation field.
